@@ -1,6 +1,5 @@
-from typing import List, TypeVar, Union, Callable, Tuple
-
 from numbers import Integral
+from typing import List, TypeVar, Union, Callable, Tuple, Optional
 
 
 def f0(x: int, y: Integral) -> None:
@@ -35,14 +34,47 @@ def f5(x: int, *, y: str, z: str) -> None:
     pass
 
 
-def f6(x: int = None, y: dict = {}) -> None:
+def f6(x: int, *args, y: str, z: str) -> None:
     pass
 
 
-def f7(x: Callable[[int, str], int]) -> None:
+def f7(x: int = None, y: dict = {}) -> None:
+    pass
+
+
+def f8(x: Callable[[int, str], int]) -> None:
     # See https://github.com/ambv/typehinting/issues/149 for Callable[..., int]
     pass
 
 
-def f8(x: Tuple[int, str], y: Tuple[int, ...]) -> None:
+def f9(x: Callable) -> None:
     pass
+
+
+def f10(x: Tuple[int, str], y: Tuple[int, ...]) -> None:
+    pass
+
+
+class CustomAnnotation:
+    def __repr__(self):
+        return 'CustomAnnotation'
+
+
+def f11(x: CustomAnnotation(), y: 123) -> None:
+    pass
+
+
+def f12() -> Tuple[int, str, int]:
+    pass
+
+
+def f13() -> Optional[str]:
+    pass
+
+
+class Node:
+    def __init__(self, parent: Optional['Node']) -> None:
+        pass
+
+    def children(self) -> List['Node']:
+        pass
